summaryrefslogtreecommitdiff
path: root/chromium/chrome/common/chrome_paths.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/chrome/common/chrome_paths.cc')
-rw-r--r--chromium/chrome/common/chrome_paths.cc11
1 files changed, 3 insertions, 8 deletions
diff --git a/chromium/chrome/common/chrome_paths.cc b/chromium/chrome/common/chrome_paths.cc
index e960a454868..910e99db1a4 100644
--- a/chromium/chrome/common/chrome_paths.cc
+++ b/chromium/chrome/common/chrome_paths.cc
@@ -108,10 +108,6 @@ bool GetInternalPluginsDirectory(base::FilePath* result) {
// implementations should not be used if higher-versioned component-updated
// implementations are available in DIR_USER_DATA.
bool GetComponentDirectory(base::FilePath* result) {
-#if BUILDFLAG(IS_FUCHSIA)
- // TODO(crbug.com/1241871): Support bundled components.
- return false;
-#else
#if BUILDFLAG(IS_MAC)
// If called from Chrome, return the framework's Libraries directory.
if (base::mac::AmIBundled()) {
@@ -120,12 +116,11 @@ bool GetComponentDirectory(base::FilePath* result) {
*result = result->Append("Libraries");
return true;
}
// In tests, just look in the module directory (below).
#endif
- // The rest of the world expects components in the module directory.
- return base::PathService::Get(base::DIR_MODULE, result);
-#endif
+ // The rest of the world expects components in the assets directory.
+ return base::PathService::Get(base::DIR_ASSETS, result);
}
} // namespace
@@ -120,12 +116,11 @@ bool GetComponentDirectory(base::FilePath* result) {
return true;
}
-// In tests, just look in the module directory (below).
+// In tests, just look in the assets directory (below).
#endif